@@ -1,8 +1,7 @@
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
-EventConfiguration = import_string(
-    api_settings.EVENT['configuration']['models'])
+
+EventConfiguration = import_string('EVENT.configuration.models')
 
 
 class EventConfigurationSerializer(CustomSerializer):
