@@ -1,9 +1,8 @@
 from rest_framework.routers import DefaultRouter
-from django.utils.module_loading import import_string
-from bluedot_rest_framework.settings import api_settings
+from bluedot_rest_framework import import_string
 
 
-UserView = import_string(api_settings.USER['views'])
+UserView = import_string('USER.views')
 
 router = DefaultRouter(trailing_slash=False)
 router.register(r'user', UserView, basename='user')
